// ---------------------------------------------------------------------------
// Created by F. Malpartida on 9/9/12.
// Copyright 2011 - Under creative commons license 3.0:
//        Attribution-NonCommercial-ShareAlike CC BY-NC-SA
//        http://www.electrofunltd.com
// 
// This software is furnished "as is", without technical support, and with no 
// warranty, express or implied, as to its usefulness for any purpose.
//
// Thread Safe: No
// Extendable: No
//
// @file mmi.cpp
// MMI display controller of machine's current operation.
// 
// @brief 
// MMI display controller. Basic on board information regarding temperature
// readings and current machine position.
// Requires New LiquidCrystal library to be installed in system:
//    https://bitbucket.org/fmalpartida/new-liquidcrystal/wiki/Home
//
//
// @author F. Malpartida
// ---------------------------------------------------------------------------
#include "mmi.h"

#ifdef _MMI_ENABLED_
#include <LCD.h>
#include "tempCntrl.h"
#include "stepperCntrl.h"

mmi::mmi ( void )
{
   _lcd = NULL;
   _tempCont = NULL;
   _machCntrl = NULL;
   _init = false;
}

void mmi::init ( LCD *lcd, tempCntrl *temperatureController, stepperCntrl *controller )
{
   _lcd = lcd;
   _tempCont = temperatureController;
   _machCntrl = controller;
   _init = true;

}

void mmi::display ( void )
{
   uint8_t speed;
   stepperCntrl::t_floatPoint pos;
   
   speed = _tempCont->speedGet();
   
   // Read the current temperature form the sensor
   _lcd->setCursor ( 0,0 );
   _lcd->print ( "T:" );
   _lcd->print ( _tempCont->tempGet(), 1 );
   _lcd->print ("  S:");
   _lcd->print ( speed/100 );
   _lcd->print ( (speed % 100)/10 );
   _lcd->print ( (speed % 10) );
   
   pos = _machCntrl->getPosition ();
   _lcd->setCursor ( 0, 1 );
   _lcd->print (pos.x, 1);
   _lcd->print (" ");
   _lcd->print (pos.y, 1);
   _lcd->print (" ");
   _lcd->print (pos.z, 1);
   _lcd->print (" ");
   
#ifdef _DEBUG_
   Serial.print ( _tempCont->tempGet(), 1 );
   Serial.println ( speed  );

   Serial.print (pos.x, 1);
   Serial.print (" ");
   Serial.print (pos.y, 1);
   Serial.print (" ");
   Serial.println (pos.z, 1);
#endif
}
#endif // _MMI_ENABLED_