// ---------------------------------------------------------------------------
// Created by Francisco Malpartida on 16/04/11.
// Copyright 2011 - Under creative commons license 3.0:
//        Attribution-NonCommercial-ShareAlike CC BY-NC-SA
//        http://www.electrofunltd.com
//
// This software is furnished "as is", without technical support, and with no 
// warranty, express or implied, as to its usefulness for any purpose.
//
// Thread Safe: No
// Extendable: No
//
// @file stepper.h
// File description here
// 
// @brief Stepper driver
//
// @author F. Malpartida
// ---------------------------------------------------------------------------
#include <Arduino.h>
#include "stepper.h"


stepper::stepper ( uint8_t stepPin, uint8_t dirPin, uint8_t enPin, uint8_t pulseW )
{
   _stepPin   = stepPin;
   _dirPin    = dirPin;
   _enPin     = enPin;
   _pulseW    = pulseW;
   _numSteps  = 0;
   
   pinMode ( _stepPin, OUTPUT );
   pinMode ( _dirPin, OUTPUT );
   pinMode ( _enPin, OUTPUT );
   
   digitalWrite ( _stepPin, LOW );
   digitalWrite ( _enPin, DISABLE );
   digitalWrite ( _dirPin, stepper::LEFT );
}

void stepper::runStep ( )
{
   if ( _numSteps > 0 )
   {
      digitalWrite ( _stepPin, HIGH );
      delayMicroseconds ( _pulseW );
      digitalWrite ( _stepPin, LOW );
      _numSteps--;
   }
}

void stepper::step ( )
{
   digitalWrite ( _stepPin, HIGH );
   delayMicroseconds ( _pulseW );
   digitalWrite ( _stepPin, LOW );
}


void stepper::setSteps ( uint16_t numSteps )
{
   _numSteps = numSteps;
}

uint16_t stepper::getSteps ( void )
{
   return ( _numSteps );
}

void stepper::setDirection ( t_dir direction )
{
   digitalWrite (_dirPin, direction );
}

void stepper::enable ( void )
{
   digitalWrite ( _enPin, ENABLE );
}

void stepper::disable ( void )
{
   digitalWrite ( _enPin, DISABLE );
}