// ---------------------------------------------------------------------------
// Created by F. Malpartida on 9/9/12.
// Copyright 2011 - Under creative commons license 3.0:
//        Attribution-NonCommercial-ShareAlike CC BY-NC-SA
//        http://www.electrofunltd.com
// 
// This software is furnished "as is", without technical support, and with no 
// warranty, express or implied, as to its usefulness for any purpose.
//
// Thread Safe: No
// Extendable: No
//
// @file tempCntrl.cpp
// Main temperature controller and fan interface. Senses temperature from LM75B
// and controls the fan speed to cool the electronics. 
// Requires thermistor library.
// 
// @brief 
//
//
// @author F. Malpartida
// ---------------------------------------------------------------------------
#include "tempCntrl.h"
#ifdef _TEMP_CONTROL_ENABLED_

#include <thermistor.h>
#include <lm75.h>

tempCntrl::tempCntrl ( uint8_t fanPin, uint8_t sensorAddr )
{
   _fanPin = fanPin;
   _sensorAddr = sensorAddr;
   _sensor.addressSet (sensorAddr);
   _filtTemp = 25.0;
   _speed = 175;

}

void tempCntrl::init ( void )
{  
   pinMode ( _fanPin, OUTPUT );
   analogWrite ( _fanPin, 150 );
   _sensor.init();
   if ( _sensor.isAvailable() == true )
   {
      _filtTemp = _sensor.readTemperature();  // Initialise the filter to the first
   }
   
}

double tempCntrl::tempGet ( void )
{
   return ( _filtTemp );
}

uint8_t tempCntrl::speedGet ( void )
{
   return ( _speed );
}

void tempCntrl::fanControl ( double avrTemp )
{   
   if ( avrTemp > MAX_TEMP )
   {
      _speed = MAX_SPEED;
      analogWrite ( FAN_PIN, _speed );
   }
   else if ( avrTemp > START_TEMP )
   {
      _speed = (avrTemp - START_TEMP) * TEMP_SPEED_INC;
      analogWrite ( FAN_PIN, _speed );
   }
   else
   {
      _speed = 0;
      analogWrite ( FAN_PIN, _speed );
   }
}


void tempCntrl::controlTemp ( void )
{
   double currentTemp;  
   
   if (_sensor.isAvailable () )
   {
      currentTemp = _sensor.readTemperature();
      _filtTemp = ( FILTER_ALP * currentTemp) + (( 1.0 - FILTER_ALP ) * _filtTemp);
   }   
   fanControl ( _filtTemp );
}
#endif //_TEMP_CONTROL_ENABLED_